@@ -19,7 +19,6 @@ use nix::{errno::Errno, mount, sched};
 use regex::Regex;
 use std::collections::{HashMap, HashSet};
 use std::convert::TryInto;
-use std::env;
 use std::fs::{
     canonicalize, metadata, read_dir, read_to_string, remove_dir, symlink_metadata, File,
     OpenOptions,
@@ -32,7 +31,6 @@ use std::os::unix::fs::FileTypeExt;
 use std::os::unix::io::AsRawFd;
 use std::path::{Path, PathBuf};
 use std::process::Command;
-use std::sync::Once;
 use std::thread::sleep;
 use std::time::Duration;
 use uuid::Uuid;
@@ -138,7 +136,7 @@ impl Disk {
                 .write(true)
                 .open(&self.path)
                 .with_context(|| format!("opening {}", &self.path))?;
-            reread_partition_table(&mut f).map(|_| Vec::new())
+            reread_partition_table(&mut f, false).map(|_| Vec::new())
         };
         if rereadpt_result.is_ok() {
             return rereadpt_result;
@@ -214,7 +212,7 @@ impl PartTableKernel {
 
 impl PartTable for PartTableKernel {
     fn reread(&mut self) -> Result<()> {
-        reread_partition_table(&mut self.file)?;
+        reread_partition_table(&mut self.file, true)?;
         udev_settle()
     }
 }
@@ -424,25 +422,8 @@ impl Mount {
 
         // Ensure we're in a private mount namespace so the mount isn't
         // visible to the rest of the system.  Multiple unshare calls
-        // should be safe.  For now, skip the unshare if the
-        // COREOS_INSTALLER_NO_MOUNT_NAMESPACE environment variable is set,
-        // in case there are use cases where the unshare call fails.
-        // https://github.com/coreos/coreos-installer/issues/557
-        match env::var("COREOS_INSTALLER_NO_MOUNT_NAMESPACE")
-            .as_ref()
-            .map(|v| v as &str)
-        {
-            Ok("") | Err(env::VarError::NotPresent) => {
-                sched::unshare(sched::CloneFlags::CLONE_NEWNS)
-                    .context("unsharing mount namespace")?
-            }
-            _ => {
-                static WARNED: Once = Once::new();
-                WARNED.call_once(|| {
-                    eprintln!("\nMounting filesystems in parent namespace because\nCOREOS_INSTALLER_NO_MOUNT_NAMESPACE is set.  If you need this, file a bug at\nhttps://github.com/coreos/coreos-installer/issues/new/choose.\n");
-                });
-            }
-        }
+        // should be safe.
+        sched::unshare(sched::CloneFlags::CLONE_NEWNS).context("unsharing mount namespace")?;
 
         mount::mount::<str, Path, str, str>(Some(device), &mountpoint, Some(fstype), flags, None)
             .with_context(|| format!("mounting device {} on {}", device, mountpoint.display()))?;
@@ -801,11 +782,11 @@ pub fn lsblk_single(dev: &Path) -> Result<HashMap<String, String>> {
     Ok(devinfos.remove(0))
 }
 
-/// Rereads partition table and than returns all available filesystems
-/// rereading mitigates possble issue with outdated UUIDs on different
+/// Returns all available filesystems.
+/// rereadpt mitigates possible issue with outdated UUIDs on different
 /// paths to the same disk: after 'ignition-ostree-firstboot-uuid'
 /// '/dev/sdaX' path gets new UUID, but '/dev/sdbX/' path has an old one
-fn lsblk_all_and_reread_partition_tables() -> Result<Vec<HashMap<String, String>>> {
+fn lsblk_all(rereadpt: bool) -> Result<Vec<HashMap<String, String>>> {
     let mut cmd = Command::new("lsblk");
     cmd.arg("--noheadings")
         .arg("--nodeps")
@@ -814,12 +795,15 @@ fn lsblk_all_and_reread_partition_tables() -> Result<Vec<HashMap<String, String>
         .arg("--output")
         .arg("NAME");
     let output = cmd_output(&mut cmd)?;
-    for dev in output.lines() {
-        if let Ok(mut fd) = std::fs::File::open(dev) {
-            let _ = reread_partition_table(&mut fd);
+    if rereadpt {
+        for dev in output.lines() {
+            if let Ok(mut fd) = std::fs::File::open(dev) {
+                // best-effort reread of disk that may have busy partitions; don't retry
+                let _ = reread_partition_table(&mut fd, false);
+            }
         }
+        udev_settle()?;
     }
-    udev_settle()?;
     let mut result: Vec<HashMap<String, String>> = Vec::new();
     for dev in output.lines() {
         let mut info = lsblk(Path::new(dev), true)?;
@@ -830,9 +814,9 @@ fn lsblk_all_and_reread_partition_tables() -> Result<Vec<HashMap<String, String>
 
 /// Returns filesystems with given label.
 /// If multiple filesystems with the label have the same UUID, we only return one of them.
-pub fn get_filesystems_with_label(label: &str) -> Result<Vec<String>> {
+pub fn get_filesystems_with_label(label: &str, rereadpt: bool) -> Result<Vec<String>> {
     let mut uuids = HashSet::new();
-    let result = lsblk_all_and_reread_partition_tables()?
+    let result = lsblk_all(rereadpt)?
         .iter()
         .filter(|v| v.get("LABEL").map(|l| l.as_str()) == Some(label))
         .filter(|v| match v.get("UUID") {
@@ -1010,11 +994,12 @@ pub fn get_blkdev_deps_recursing(device: &Path) -> Result<Vec<PathBuf>> {
     Ok(ret)
 }
 
-fn reread_partition_table(file: &mut File) -> Result<()> {
+fn reread_partition_table(file: &mut File, retry: bool) -> Result<()> {
     let fd = file.as_raw_fd();
     // Reread sometimes fails inexplicably.  Retry several times before
     // giving up.
-    for retries in (0..20).rev() {
+    let max_tries = if retry { 20 } else { 1 };
+    for retries in (0..max_tries).rev() {
         let result = unsafe { ioctl::blkrrpart(fd) };
         match result {
             Ok(_) => break,
