@@ -58,6 +58,14 @@ pub enum Cmd {
     Osmet(OsmetCmd),
     /// Commands to manage a CoreOS live PXE image
     Pxe(PxeCmd),
+    /// Metadata packing commands used when building an OS image
+    // users shouldn't be interacting with this command normally
+    #[structopt(setting(AppSettings::Hidden))]
+    Pack(PackCmd),
+    /// Development commands (unstable)
+    // users shouldn't be interacting with this command normally
+    #[structopt(setting(AppSettings::Hidden))]
+    Dev(DevCmd),
 }
 
 #[derive(Debug, StructOpt)]
@@ -82,10 +90,6 @@ pub enum IsoCmd {
     Network(IsoNetworkCmd),
     /// Modify kernel args in a CoreOS live ISO image
     Kargs(IsoKargsCmd),
-    /// Inspect the CoreOS live ISO image
-    // for testing and debugging purposes only
-    #[structopt(setting(AppSettings::Hidden))]
-    Inspect(IsoInspectConfig),
     /// Commands to extract files from a CoreOS live ISO image
     Extract(IsoExtractCmd),
     /// Restore a CoreOS live ISO image to default settings
@@ -128,21 +132,17 @@ pub enum IsoExtractCmd {
     Pxe(IsoExtractPxeConfig),
     /// Extract a minimal ISO from a CoreOS live ISO image
     MinimalIso(IsoExtractMinimalIsoConfig),
-    // This doesn't really make sense under `extract`, but it's hidden and conceptually feels
-    // cleaner being alongside `coreos-installer iso extract minimal-iso`.
     /// Pack a minimal ISO into a CoreOS live ISO image
+    // deprecated in favor of "pack minimal-iso"
     #[structopt(setting(AppSettings::Hidden))]
-    PackMinimalIso(IsoExtractPackMinimalIsoConfig),
+    PackMinimalIso(PackMinimalIsoConfig),
 }
 
 #[derive(Debug, StructOpt)]
 pub enum OsmetCmd {
     /// Create osmet file from CoreOS block device
-    Pack(OsmetPackConfig),
-    /// Generate raw metal image from osmet file and OSTree repo
-    Unpack(OsmetUnpackConfig),
-    /// Print file extent mapping of specific file
-    Fiemap(OsmetFiemapConfig),
+    // deprecated in favor of "pack osmet"
+    Pack(PackOsmetConfig),
 }
 
 #[derive(Debug, StructOpt)]
@@ -171,6 +171,40 @@ pub enum PxeNetworkCmd {
     Unwrap(PxeNetworkUnwrapConfig),
 }
 
+#[derive(Debug, StructOpt)]
+pub enum PackCmd {
+    /// Create osmet file from CoreOS block device
+    Osmet(PackOsmetConfig),
+    /// Pack a minimal ISO into a CoreOS live ISO image
+    MinimalIso(PackMinimalIsoConfig),
+}
+
+#[derive(Debug, StructOpt)]
+pub enum DevCmd {
+    /// Commands to show metadata
+    Show(DevShowCmd),
+    /// Commands to extract data
+    Extract(DevExtractCmd),
+}
+
+#[derive(Debug, StructOpt)]
+pub enum DevShowCmd {
+    /// Inspect the CoreOS live ISO image
+    Iso(DevShowIsoConfig),
+    /// Show the contents of an initrd image
+    Initrd(DevShowInitrdConfig),
+    /// Print file extent mapping of specific file
+    Fiemap(DevShowFiemapConfig),
+}
+
+#[derive(Debug, StructOpt)]
+pub enum DevExtractCmd {
+    /// Generate raw metal image from osmet file and OSTree repo
+    Osmet(DevExtractOsmetConfig),
+    /// Extract the contents of an initrd image
+    Initrd(DevExtractInitrdConfig),
+}
+
 // As a special case, this struct supports Serialize and Deserialize for
 // config file parsing.  Here are the rules.  Build or test should fail if
 // you break anything too badly.
@@ -630,9 +664,6 @@ pub struct IsoIgnitionShowConfig {
     /// ISO image
     #[structopt(value_name = "ISO")]
     pub input: String,
-    /// Show ISO header (for debugging/testing only)
-    #[structopt(long, hidden = true)]
-    pub header: bool,
 }
 
 #[derive(Debug, StructOpt)]
@@ -718,16 +749,19 @@ pub struct IsoKargsShowConfig {
     /// Show default kernel args
     #[structopt(short, long)]
     pub default: bool,
-    /// Show ISO header (for debugging/testing only)
-    #[structopt(long, hidden = true)]
-    pub header: bool,
     /// ISO image
     #[structopt(value_name = "ISO")]
     pub input: String,
 }
 
 #[derive(Debug, StructOpt)]
-pub struct IsoInspectConfig {
+pub struct DevShowIsoConfig {
+    /// Show Ignition embed area parameters
+    #[structopt(long, conflicts_with = "kargs")]
+    pub ignition: bool,
+    /// Show kargs embed area parameters
+    #[structopt(long, conflicts_with = "ignition")]
+    pub kargs: bool,
     /// ISO image
     #[structopt(value_name = "ISO")]
     pub input: String,
@@ -760,7 +794,7 @@ pub struct IsoExtractMinimalIsoConfig {
 }
 
 #[derive(Debug, StructOpt)]
-pub struct IsoExtractPackMinimalIsoConfig {
+pub struct PackMinimalIsoConfig {
     /// ISO image
     #[structopt(value_name = "FULL_ISO")]
     pub full: String,
@@ -783,7 +817,9 @@ pub struct IsoResetConfig {
 }
 
 #[derive(Debug, StructOpt)]
-pub struct OsmetPackConfig {
+// default usage line lists all mandatory options and so exceeds 80 characters
+#[structopt(usage = "coreos-installer pack osmet [OPTIONS]")]
+pub struct PackOsmetConfig {
     /// Path to osmet file to write
     // could output to stdout if missing?
     #[structopt(long, required = true, value_name = "FILE")]
@@ -806,7 +842,7 @@ pub struct OsmetPackConfig {
 }
 
 #[derive(Debug, StructOpt)]
-pub struct OsmetUnpackConfig {
+pub struct DevExtractOsmetConfig {
     /// osmet file
     #[structopt(long, required = true, value_name = "PATH")]
     pub osmet: String,
@@ -819,7 +855,7 @@ pub struct OsmetUnpackConfig {
 }
 
 #[derive(Debug, StructOpt)]
-pub struct OsmetFiemapConfig {
+pub struct DevShowFiemapConfig {
     /// File to map
     #[structopt(value_name = "PATH")]
     pub file: String,
@@ -880,6 +916,32 @@ pub struct PxeNetworkUnwrapConfig {
     pub input: Option<String>,
 }
 
+#[derive(Debug, StructOpt)]
+pub struct DevShowInitrdConfig {
+    /// initrd image ("-" for stdin)
+    #[structopt(value_name = "initrd")]
+    pub input: String,
+    /// Files or globs to list
+    #[structopt(value_name = "glob")]
+    pub filter: Vec<String>,
+}
+
+#[derive(Debug, StructOpt)]
+pub struct DevExtractInitrdConfig {
+    /// Output directory
+    #[structopt(short = "C", long, value_name = "path", default_value = ".")]
+    pub directory: String,
+    /// List extracted contents
+    #[structopt(short, long)]
+    pub verbose: bool,
+    /// initrd image ("-" for stdin)
+    #[structopt(value_name = "initrd")]
+    pub input: String,
+    /// Files or globs to list
+    #[structopt(value_name = "glob")]
+    pub filter: Vec<String>,
+}
+
 impl FromStr for FetchRetries {
     type Err = Error;
     fn from_str(s: &str) -> Result<Self, Self::Err> {
